==> enhydris-cache-1.0.2.tar.gz: enhydris-cache-1.0.2/setup.py <==
#!/usr/bin/env python

import os
import re

from setuptools import find_packages, setup

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = ["Click>=7.0", "enhydris-api-client>=2.0.1,<4"]

test_requirements = []


def get_version():
    scriptdir = os.path.dirname(os.path.abspath(__file__))
    init_py_path = os.path.join(scriptdir, "enhydris_cache", "__init__.py")
    with open(init_py_path) as f:
        return re.search(r'^__version__ = "(.*?)"$', f.read(), re.MULTILINE).group(1)


setup(
    author="Antonis Christofides",
    author_email="antonis@antonischristofides.com",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    description="Utilities for spatial integration of time series",
    entry_points={"console_scripts": ["enhydris-cache=enhydris_cache.cli:main"]},
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + "\n\n" + history,
    long_description_content_type="text/x-rst",
    include_package_data=True,
    keywords="enhydris-cache",
    name="enhydris-cache",
    packages=find_packages(include=["enhydris_cache"]),
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/openmeteo/enhydris-cache",
    version=get_version(),
    zip_safe=False,
)

==> enhydris-cache-2.0.0.tar.gz: enhydris-cache-2.0.0/setup.py <==
#!/usr/bin/env python

import os
import re

from setuptools import find_packages, setup

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = ["Click>=7.0", "enhydris-api-client>=4,<5"]

test_requirements = []


def get_version():
    scriptdir = os.path.dirname(os.path.abspath(__file__))
    init_py_path = os.path.join(scriptdir, "enhydris_cache", "__init__.py")
    with open(init_py_path) as f:
        return re.search(r'^__version__ = "(.*?)"$', f.read(), re.MULTILINE).group(1)


setup(
    author="Antonis Christofides",
    author_email="antonis@antonischristofides.com",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    description="Utilities for spatial integration of time series",
    entry_points={"console_scripts": ["enhydris-cache=enhydris_cache.cli:main"]},
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + "\n\n" + history,
    long_description_content_type="text/x-rst",
    include_package_data=True,
    keywords="enhydris-cache",
    name="enhydris-cache",
    packages=find_packages(include=["enhydris_cache"]),
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/openmeteo/enhydris-cache",
    version=get_version(),
    zip_safe=False,
)
